@@ -46,6 +46,10 @@ class Method(Base):
     def maximum_amount(self):
         return self._get_property('maximumAmount')
 
+    @property
+    def pricing(self):
+        return self._get_property('pricing')
+
     @property
     def image_svg(self):
         try:
